@@ -14,7 +14,8 @@
 ## this program; if not, see <http://www.gnu.org/licenses/>.
 
 
-if((Rv <- getRversion()) < "3.2.0") {
+if((Rv <- getRversion()) < "3.5.0") {
+  if(Rv < "3.2.0") {
     lengths <- function (x, use.names = TRUE) vapply(x, length, 1L, USE.NAMES = use.names)
     ## now have  Depends: R (>= 3.1.0)
     ## if(Rv < "3.1.0") {
@@ -25,8 +26,11 @@ if((Rv <- getRversion()) < "3.2.0") {
     ##             paste0 <- function(...) paste(..., sep = '')
     ##     }
     ## }
-} ## R < 3.2.0
+  } ## R < 3.2.0
 
+  isTRUE  <- function (x) is.logical(x) && length(x) == 1L && !is.na(x) &&  x
+  isFALSE <- function (x) is.logical(x) && length(x) == 1L && !is.na(x) && !x
+}
 
 #### Functions and Methods for "acopula" objects
 #### class definition in ./AllClass.R
